@@ -228,7 +228,7 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
     if (!line.isNull ()) {
         if (cur_elm->isPlayable ())
             cur_elm = cur_elm->mrl ()->linkNode ();
-        if (cur_elm->mrl ()->mimetype == String ("audio/x-scpls")) {
+        if (cur_elm->mrl ()->mimetype == "audio/x-scpls") {
             bool groupfound = false;
             int nr = -1;
             struct Entry {
@@ -238,7 +238,7 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
                 line = line.stripWhiteSpace ();
                 if (!line.isEmpty ()) {
                     if (line.startsWith (String ("[")) && line.endsWith (String ("]"))) {
-                        if (!groupfound && line.mid (1, line.length () - 2).stripWhiteSpace () == String ("playlist"))
+                        if (!groupfound && line.mid (1, line.length () - 2).stripWhiteSpace () == "playlist")
                             groupfound = true;
                         else
                             break;
@@ -276,7 +276,7 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
         } else if (line.stripWhiteSpace ().startsWith (Char ('<'))) {
             readXML (cur_elm, textstream, line);
             //cur_elm->normalize ();
-        } else if (line.lower () != String ("[reference]")) {
+        } else if (line.lower () != "[reference]") {
             bool extm3u = line.startsWith ("#EXTM3U");
             String title;
             NodePtr doc = node->document ();
@@ -285,7 +285,7 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
             while (!line.isNull ()) {
              /* TODO && m_document.size () < 1024 / * support 1k entries * /);*/
                 String mrl = line.stripWhiteSpace ();
-                if (line == String ("--stop--"))
+                if (line == "--stop--")
                     break;
                 if (mrl.lower ().startsWith (String ("asf ")))
                     mrl = mrl.mid (4).stripWhiteSpace ();
