@@ -191,6 +191,7 @@ void app_full_screen (Application *app) {
         }
         gtk_widget_show_all (GTK_WIDGET (app->window_fullscreen));
         app->fullscreen = true;
+        app_update_screen_blanking (app);
     }
 }
 
@@ -199,6 +200,7 @@ void app_normal_screen (Application *app) {
         gtk_widget_hide (GTK_WIDGET (app->window_fullscreen));
         app->fullscreen = false;
     }
+    app_update_screen_blanking (app);
 }
 
 void app_store_save_directory (Application *app, gchar *path) {
@@ -306,8 +308,11 @@ bool cb_window_expose (GtkWidget *w, GdkEventExpose *ev, Application *app) {
 
 static void windowTopMost (GObject * self, GParamSpec *gps, Application * app) {
     (void)gps;
-    if (app->fullscreen && hildon_window_get_is_topmost (HILDON_WINDOW (app->window)))
+    app->top_most_window = hildon_window_get_is_topmost (HILDON_WINDOW (app->window));
+    if (app->fullscreen && app->top_most_window)
         app_normal_screen (app);
+    else
+        app_update_screen_blanking (app);
 }
 
 /* Create the menu items needed for the main view */
