@@ -67,7 +67,7 @@ public:
     void deactivate ();
     bool expose () const;
 
-    Posting *duration_timer;
+    Command *duration_timer;
     int ref_child_count;
 };
 
