@@ -39,7 +39,7 @@ KDE_NO_CDTOR_EXPORT FileDocument::FileDocument (short i, const String &s, KMPlay
 }
 
 KDE_NO_EXPORT KMPlayer::Node *FileDocument::childFromTag(const String &tag) {
-    if (tag == String (nodeName ()))
+    if (tag == nodeName ())
         return this;
     return NULL;
 }
@@ -86,9 +86,9 @@ KDE_NO_EXPORT void Recents::defer () {
 
 KDE_NO_EXPORT KMPlayer::Node *Recents::childFromTag (const String & tag) {
     // kdDebug () << nodeName () << " childFromTag " << tag << endl;
-    if (tag == String ("item"))
+    if (tag == "item")
         return new Recent (m_doc, app);
-    else if (tag == String ("group"))
+    else if (tag == "group")
         return new Group (m_doc, app);
     return FileDocument::childFromTag (tag);
 }
@@ -133,9 +133,9 @@ Group::Group (KMPlayer::NodePtr & doc, Application * a, const String & pn)
 }
 
 KDE_NO_EXPORT KMPlayer::Node *Group::childFromTag (const String & tag) {
-    if (tag == String ("item"))
+    if (tag == "item")
         return new Recent (m_doc, app);
-    else if (tag == String ("group"))
+    else if (tag == "group")
         return new Group (m_doc, app);
     return NULL;
 }
