@@ -43,9 +43,9 @@ KDE_NO_EXPORT void RP::Imfl::closed () {
             Attribute *a = convertNode <Element> (n)->attributes ()->first ();
             for (; a; a = a->nextSibling ()) {
                 if (StringPool::attr_width == a->name ()) {
-                    width = a->value ().toInt ();
+                    size.width = a->value ().toInt ();
                 } else if (StringPool::attr_height == a->name ()) {
-                    height = a->value ().toInt ();
+                    size.height = a->value ().toInt ();
                 } else if (a->name () == "duration") {
                     int dur;
                     parseTime (a->value ().lower (), dur);
@@ -86,8 +86,8 @@ KDE_NO_EXPORT void RP::Imfl::activate () {
                 break;
         }
     if (duration > 0)
-        duration_timer = document ()->post (this,
-                new TimerPosting (duration * 100));
+        duration_timer = document ()->post (
+                new TimerPosting (this, duration * 100));
     else if (!timings_count)
         finish ();
 }
@@ -155,12 +155,8 @@ KDE_NO_EXPORT void RP::Imfl::accept (Visitor * v) {
 KDE_NO_EXPORT Surface *RP::Imfl::surface () {
     if (!rp_surface) {
         rp_surface = (Surface *) Mrl::message (MsgQueryRoleChildDisplay, this);
-        if (rp_surface) {
-            if (width <= 0 || width > 32000)
-                width = rp_surface->bounds.width ();
-            if (height <= 0 || height > 32000)
-                height = rp_surface->bounds.height ();
-        }
+        if (rp_surface && size.isEmpty ())
+            size = rp_surface->bounds.size;
     }
     return rp_surface.ptr ();
 }
@@ -189,9 +185,9 @@ KDE_NO_EXPORT Node *RP::Imfl::childFromTag (const String & tag) {
 KDE_NO_EXPORT void RP::Imfl::repaint () {
     if (!active ()) {
         warningLog () << "Spurious Imfl repaint" << endl;
-    } else if (surface () && width > 0 && height > 0) {
+    } else if (surface () && !size.isEmpty ()) {
         rp_surface->markDirty ();
-        rp_surface->repaint (SRect (0, 0, width, height));
+        rp_surface->repaint (SRect (0, 0, size));
     }
 }
 
@@ -244,8 +240,8 @@ KDE_NO_EXPORT void *RP::Image::message (MessageType msg, void *content) {
 KDE_NO_EXPORT void RP::Image::dataArrived () {
     ImageActor *im = media_info->media ? (ImageActor *)media_info->media : NULL;
     if (!im->isEmpty ()) {
-        width = im->cached_img->width;
-        height = im->cached_img->height;
+        size.width = im->cached_img->width;
+        size.height = im->cached_img->height;
     }
     postpone_lock = 0L;
 }
@@ -265,7 +261,7 @@ KDE_NO_EXPORT Surface *RP::Image::surface () {
             Surface *ps = static_cast <RP::Imfl *> (p)->surface ();
             if (ps)
                 img_surface = ps->createSurface (this,
-                        SRect (0, 0, width, height));
+                        SRect (0, 0, size));
         }
     }
     return img_surface;
@@ -313,7 +309,7 @@ KDE_NO_EXPORT void RP::TimingsBase::activate () {
             srch = a->value ().toInt ();
         }
     }
-    start_timer = document ()->post (this, new TimerPosting (start *100));
+    start_timer = document ()->post (new TimerPosting (this, start *100));
 }
 
 KDE_NO_EXPORT void RP::TimingsBase::deactivate () {
@@ -333,8 +329,8 @@ KDE_NO_EXPORT void *RP::TimingsBase::message (MessageType msg, void *content) {
                 te->interval = true;
             } else if (te == start_timer) {
                 start_timer = 0;
-                duration_timer = document()->post (this,
-                        new TimerPosting (duration * 100));
+                duration_timer = document()->post (
+                        new TimerPosting (this, duration * 100));
                 begin ();
             } else if (te == duration_timer) {
                 duration_timer = 0;
@@ -364,7 +360,7 @@ KDE_NO_EXPORT void RP::TimingsBase::begin () {
         target->begin ();
     if (duration > 0) {
         steps = duration / 2; // 5/s updates
-        update_timer = document ()->post (this, new TimerPosting (200)); // 200ms
+        update_timer = document ()->post (new TimerPosting (this, 200)); // 200ms
         curr_step = 1;
     }
 }
