@@ -147,10 +147,10 @@ public:
     NodeRefListPtr m_StartListeners;        // Element about to be started
     NodeRefListPtr m_StartedListeners;      // Element is started
     NodeRefListPtr m_StoppedListeners;      // Element stopped
-    Posting *begin_timer;
-    Posting *duration_timer;
-    Posting *started_timer;
-    Posting *stopped_timer;
+    Command *begin_timer;
+    Command *duration_timer;
+    Command *started_timer;
+    Command *stopped_timer;
     NodePtrW paused_by;
     unsigned int start_time;
     unsigned int finish_time;
@@ -613,7 +613,7 @@ public:
     unsigned int trans_start_time;
     unsigned int trans_end_time;
     float trans_gain;
-    Posting *trans_out_timer;
+    Command *trans_out_timer;
     enum { sens_opaque, sens_transparent, sens_percentage } sensitivity;
     bool trans_out_active;
     bool has_mouse;
@@ -786,7 +786,7 @@ public:
     KDE_NO_EXPORT const char * nodeName () const { return "animate"; }
     PlayType playType () { return play_type_none; }
 
-    Posting *anim_timer;
+    Command *anim_timer;
 private:
     void applyStep ();
     bool timerTick();
@@ -820,7 +820,7 @@ public:
     KDE_NO_EXPORT const char * nodeName () const { return "animateMotion"; }
     PlayType playType () { return play_type_none; }
 
-    Posting *anim_timer;
+    Command *anim_timer;
 private:
     bool timerTick (unsigned int cur_time);
     bool checkTarget (Node *n);
