@@ -242,12 +242,17 @@ void Control::deinit () {
     delete downloader;
 }
 
-gboolean cb_blankingTimer (void * p) {
-    Application * app = static_cast <Application *> (p);
-    if (CONTROL(app)->playlist_data->current &&
-            (CONTROL(app)->playlist_data->current->id == SMIL::id_node_smil ||
-             (CONTROL(app)->process ()->playing () &&
-              CONTROL(app)->process ()->hasVideo ()))) {
+static bool needsScreenBlanking (Application *app) {
+    return (app->top_most_window || app->fullscreen) &&
+        CONTROL(app)->playlist_data->current &&
+        (CONTROL(app)->playlist_data->current->id == SMIL::id_node_smil ||
+         (CONTROL(app)->process ()->playing () &&
+          CONTROL(app)->process ()->hasVideo ()));
+}
+
+gboolean cb_blankingTimer (void *p) {
+    Application *app = static_cast <Application *> (p);
+    if (needsScreenBlanking (app)) {
         osso_display_blanking_pause (app->osso_context);
         return 1;
     }
@@ -291,10 +296,6 @@ void Control::play () {
 void Control::stop (bool keep_fullscreen) {
     debugLog () << "stop" << endl;
     setLoading (100); // no pogress bar
-    if (blanking_timer) {
-        g_source_remove (blanking_timer);
-        blanking_timer = 0;
-    }
     back_request = 0L;
     if (playlist_data->document &&
             playlist_data->document->state > Node::state_init) {
@@ -350,6 +351,7 @@ void Control::stop (bool keep_fullscreen) {
                     VIEWAREA(m_app)->width (), VIEWAREA(m_app)->height ()));
     if (!keep_fullscreen)
         app_normal_screen (m_app);
+    app_update_screen_blanking (m_app);
     setLength (0);
     setPosition (0);
     updatePlaylistView ();
@@ -598,16 +600,7 @@ bool Control::setCurrent (NodePtr n) {
     playlist_data->current = n;
     current_selected = n;
     updatePlaylistView ();
-    Mrl * mrl = n ? n->mrl () : 0L;
-    if (mrl && (playlist_data->current->id == SMIL::id_node_smil ||
-                !mrl->linkNode ()->audio_only)) {
-        if (!blanking_timer)
-            blanking_timer = g_timeout_add (25000, cb_blankingTimer, m_app);
-        osso_display_blanking_pause (m_app->osso_context); // 60s delay
-    } else if (blanking_timer) {
-        g_source_remove (blanking_timer);
-        blanking_timer = 0;
-    }
+    Mrl *mrl = n ? n->mrl () : 0L;
     if (mrl) {
         String url;
         while (mrl) {
@@ -624,6 +617,7 @@ bool Control::setCurrent (NodePtr n) {
         }
         app_insert_location (m_app, (const char *)url);
     }
+    app_update_screen_blanking (m_app);
     return true;
 }
 
@@ -733,10 +727,8 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
             if (playlist_data->document &&
                     playlist_data->document->state > Node::state_init) {
                 stop (); // this should not happen
-            } else if (blanking_timer) {
-                g_source_remove (blanking_timer);
-                blanking_timer = 0;
             }
+            app_update_screen_blanking (m_app);
             if (p == downloader &&
                     !((Downloader *) downloader)->saved_file.isEmpty ())
                 addRecent (((Downloader *) downloader)->saved_file,
@@ -799,6 +791,7 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
         addRecent (playlist_data->document->mrl()->src,
                 playlist_data->document->caption ());
         updatePlayTree (m_app);
+        app_update_screen_blanking (m_app);
     }
 }
 
@@ -946,6 +939,7 @@ Application *app_new () {
     app->control = new Control (app);
     StringPool::init();
     app->viewarea = new ViewArea;
+    app->top_most_window = true;
     return app;
 }
 
@@ -959,6 +953,17 @@ void app_init_control (Application *app) {
     CONTROL(app)->init ();
 }
 
+void app_update_screen_blanking (Application *a) {
+    bool needs_blanking_pause = needsScreenBlanking (a);
+    if (needs_blanking_pause && !CONTROL(a)->blanking_timer) {
+        CONTROL(a)->blanking_timer = g_timeout_add (25000, cb_blankingTimer, a);
+        osso_display_blanking_pause (a->osso_context); // 60s delay
+    } else if (!needs_blanking_pause && CONTROL(a)->blanking_timer) {
+        g_source_remove (CONTROL(a)->blanking_timer);
+        CONTROL(a)->blanking_timer = 0;
+    }
+}
+
 static Mrl *findFirstPlayable (Node *n) {
     if (n) {
         if (n->isPlayable ())
