@@ -1519,6 +1519,63 @@ void KMPlayer::readXML (NodePtr root, TextStream & in, const String & firstline,
 
 namespace {
 
+struct MemoryPool {
+    void **used;
+    void **unused;
+    size_t size;
+    int used_count;
+    int unused_count;
+    int used_size;
+    int unused_size;
+    void *alloc ();
+    void dealloc (void *p);
+    MemoryPool (size_t s)
+        : used (NULL), unused (NULL), size (s),
+          used_count (0), unused_count (0),
+          used_size (0), unused_size (0) {}
+};
+
+
+} // namespace
+
+void *MemoryPool::alloc () {
+    if (used_size == used_count) {
+        void **tmp = (void **) malloc (++used_size * sizeof (void *));
+        if (used_count) {
+            memcpy (tmp, used, used_count * sizeof (void *));
+            free (used);
+        }
+        used = tmp;
+    }
+    void *p;
+    if (unused_count)
+        p = unused[--unused_count];
+    else
+        p = malloc (size);
+    used[used_count++] = p;
+    return p;
+}
+
+void MemoryPool::dealloc (void *p) {
+    for (int i = 0; i < used_count; ++i)
+        if (p == used[i]) {
+            if (unused_size == unused_count) {
+                void **tmp = (void **) malloc (++unused_size * sizeof (void*));
+                if (unused_count) {
+                    memcpy (tmp, unused, unused_count * sizeof (void *));
+                    free (unused);
+                }
+                unused = tmp;
+            }
+            unused[unused_count++] = p;
+            if (i < --used_count)
+                used[i] = used[used_count];
+            break;
+        }
+}
+
+namespace {
+
 class SimpleSAXParser {
     enum Token { tok_empty, tok_text, tok_white_space, tok_angle_open,
         tok_equal, tok_double_quote, tok_single_quote, tok_angle_close,
@@ -1535,7 +1592,7 @@ public:
     };
     typedef SharedPtr <TokenInfo> TokenInfoPtr;
     SimpleSAXParser (DocumentBuilder & b) : builder (b), position (0), m_attributes (new AttributeList), equal_seen (false), in_dbl_quote (false), in_sngl_quote (false), have_error (false), no_entitity_look_ahead (false), have_next_char (false) {}
-    virtual ~SimpleSAXParser () {};
+    ~SimpleSAXParser ();
     bool parse (TextStream & d);
 private:
     TextStream * data;
@@ -1577,68 +1634,29 @@ private:
     void push_attribute ();
 };
 
-static struct TokenPool {
-    void **used;
-    void **unused;
-    int used_count;
-    int unused_count;
-    int used_size;
-    int unused_size;
-    void *alloc ();
-    void dealloc (void *p);
-    TokenPool ()
-        : used (NULL), unused (NULL),
-          used_count (0), unused_count (0),
-          used_size (0), unused_size (0) {}
-} token_pool;
-
 } // namespace
 
-inline void *TokenPool::alloc () {
-    if (used_size == used_count) {
-        void **tmp = (void **) malloc (++used_size * sizeof (void *));
-        if (used_count) {
-            memcpy (tmp, used, used_count * sizeof (void *));
-            free (used);
-        }
-        used = tmp;
-    }
-    void *p;
-    if (unused_count)
-        p = unused[--unused_count];
-    else
-        p = malloc (sizeof (SimpleSAXParser::TokenInfo));
-    used[used_count++] = p;
-    return p;
-}
+static MemoryPool token_pool (sizeof (SimpleSAXParser::TokenInfo));
+static MemoryPool shared_token_pool (sizeof (SharedData <SimpleSAXParser::TokenInfo>));
 
-inline void TokenPool::dealloc (void *p) {
-    for (int i = 0; i < used_count; ++i)
-        if (p == used[i]) {
-            if (unused_size == unused_count) {
-                void **tmp = (void **) malloc (++unused_size * sizeof (void*));
-                if (unused_count) {
-                    memcpy (tmp, unused, unused_count * sizeof (void *));
-                    free (unused);
-                }
-                unused = tmp;
-            }
-            unused[unused_count++] = p;
-            if (i < used_count-1)
-                used[i] = used[used_count-1];
-            --used_count;
-            break;
-        }
-}
-
-void *SimpleSAXParser::TokenInfo::operator new (size_t s) {
+inline void *SimpleSAXParser::TokenInfo::operator new (size_t s) {
     return token_pool.alloc ();
 }
 
-void SimpleSAXParser::TokenInfo::operator delete (void *p) {
+inline void SimpleSAXParser::TokenInfo::operator delete (void *p) {
     token_pool.dealloc (p);
 }
 
+template <> inline
+void *SharedData<SimpleSAXParser::TokenInfo>::operator new (size_t s) {
+    return shared_token_pool.alloc ();
+}
+
+template <> inline
+void SharedData<SimpleSAXParser::TokenInfo>::operator delete (void *p) {
+    shared_token_pool.dealloc (p);
+}
+
 static const Char char_semi (';');
 static const Char char_eq ('=');
 static const Char char_squot ('\'');
@@ -1647,6 +1665,8 @@ static const Char char_hash ('#');
 static const Char char_bang ('!');
 static const Char char_slash ('/');
 
+inline SimpleSAXParser::~SimpleSAXParser () {};
+
 KMPLAYER_EXPORT
 void KMPlayer::readXML (NodePtr root, TextStream & in, const String & firstline, bool set_opener) {
     DocumentBuilder builder (root, set_opener);
@@ -1747,17 +1767,17 @@ bool SimpleSAXParser::nextToken () {
                 TokenInfoPtr prev_tmp = prev_token;
                 if (nextToken () && token->token == tok_text &&
                         nextToken () && token->token == tok_semi_colon) {
-                    if (prev_token->string == String ("amp"))
+                    if (prev_token->string == "amp")
                         token->string = char_amp;
-                    else if (prev_token->string == String ("lt"))
+                    else if (prev_token->string == "lt")
                         token->string = char_lt;
-                    else if (prev_token->string == String ("gt"))
+                    else if (prev_token->string == "gt")
                         token->string = char_gt;
-                    else if (prev_token->string == String ("quot"))
+                    else if (prev_token->string == "quot")
                         token->string = char_quot;
-                    else if (prev_token->string == String ("apos"))
+                    else if (prev_token->string == "apos")
                         token->string = char_squot;
-                    else if (prev_token->string == String ("copy"))
+                    else if (prev_token->string == "copy")
                         token->string = Char (169);
                     else
                         token->string = char_qu;// TODO lookup more ..
@@ -1898,7 +1918,7 @@ bool SimpleSAXParser::readAttributes () {
     }
     m_state = m_state->next;
     if (m_state->state == InPITag) {
-        if (tagname == String ("xml")) {
+        if (tagname == "xml") {
             /*const AttributeMap::const_iterator e = attr.end ();
             for (AttributeMap::const_iterator i = attr.begin (); i != e; ++i)
                 if (!strcasecmp (i.key ().latin1 (), "encoding"))
