@@ -34,7 +34,6 @@ namespace KMPlayer {
 class Document;
 class Node;
 class TextNode;
-class Posting;
 class Mrl;
 class ElementPrivate;
 class Visitor;
@@ -576,8 +575,7 @@ public:
     MediaInfo *media_info;
     String src;
     String mimetype;
-    Single width;
-    Single height;
+    SSize size;
     float aspect;
     int repeat;
     unsigned int clip_begin;
@@ -616,15 +614,29 @@ public:
     virtual void enableRepaintUpdaters (bool enable, unsigned int off_time)=0;
 };
 
+struct KMPLAYER_EXPORT Command {
+    virtual void apply (struct timeval &timeout) = 0;
+    virtual bool postponable () const = 0;
+    virtual int delay () const = 0;
+    virtual void removed () = 0;
+};
+
 /*
  *  A generic type for posting messages
  **/
-class KMPLAYER_EXPORT Posting {
+class KMPLAYER_EXPORT Posting : public Command {
 public:
-    KDE_NO_CDTOR_EXPORT Posting (Node *n, MessageType msg)
-        : source (n), message (msg) {}
+    KDE_NO_CDTOR_EXPORT Posting (Node *n, Node *tgt, MessageType msg)
+        : source (n), target (tgt), message (msg) {}
     KDE_NO_CDTOR_EXPORT virtual ~Posting () {}
+
+    virtual void apply (struct timeval &timeout);
+    virtual bool postponable () const;
+    virtual int delay () const;
+    virtual void removed ();
+
     NodePtrW source;
+    NodePtrW target;
     MessageType message;
 };
 
@@ -633,7 +645,11 @@ public:
  */
 class KMPLAYER_NO_EXPORT TimerPosting : public Posting {
 public:
-    TimerPosting (int ms, unsigned eid=0);
+    TimerPosting (Node *t, int ms, unsigned eid=0);
+
+    virtual void apply (struct timeval &timeout);
+    virtual int delay () const;
+
     unsigned event_id;
     int milli_sec;
     bool interval; // set to 'true' in 'Node::message()' to make it repeat
@@ -671,15 +687,14 @@ public:
 typedef SharedPtr <Postpone> PostponePtr;
 typedef WeakPtr <Postpone> PostponePtrW;
 
-struct KMPLAYER_NO_EXPORT EventData {
-    EventData (Node *t, Posting *e, EventData *n);
-    ~EventData ();
+struct KMPLAYER_NO_EXPORT CommandData {
+    CommandData (Command *e, CommandData *n);
+    ~CommandData ();
 
-    NodePtrW target;
-    Posting *event;
+    Command *event;
     struct timeval timeout;
 
-    EventData *next;
+    CommandData *next;
 };
 
 /**
@@ -703,10 +718,10 @@ public:
     virtual void undefer ();
     virtual void reset ();
 
-    Posting *post (Node *n, Posting *event);
-    void cancelPosting (Posting *event);
-    void pausePosting (Posting *e);
-    void unpausePosting (Posting *e, int ms);
+    Command *post (Command *event);
+    void cancelPosting (Command *event);
+    void pausePosting (Command *e);
+    void unpausePosting (Command *e, int ms);
 
     void timeOfDay (struct timeval &);
     PostponePtr postpone ();
@@ -721,20 +736,21 @@ public:
      */
     virtual void *message (MessageType msg, void *content=NULL);
 
+    void insertPosting (Command *e, const struct timeval &tv);
+
     PlayListNotify *notify_listener;
     unsigned int m_tree_version;
     unsigned int last_event_time;
 private:
     void proceed (const struct timeval & postponed_time);
-    void insertPosting (Node *n, Posting *e, const struct timeval &tv);
     void setNextTimeout (const struct timeval &now);
 
     PostponePtrW postpone_ref;
     PostponePtr postpone_lock;
     NodeRefListPtr m_PostponedListeners;
-    EventData *event_queue;
-    EventData *paused_queue;
-    EventData *cur_event;
+    CommandData *event_queue;
+    CommandData *paused_queue;
+    CommandData *cur_event;
     struct timeval first_event_time;
     int cur_time_interval;
 };
