@@ -1391,8 +1391,9 @@ static void npSetDimension (void *ndata, int w, int h) {
 }
 
 static void npGetUrl (void *inst, uint32_t stream,
-        const char *url, const char *target, void *ndata) {
-    ((NpPlayer *) ndata)->requestStream (inst, stream, url, target);
+        const char *url, const char *target,
+        unsigned plen, const char *post, void *ndata) {
+    ((NpPlayer *) ndata)->requestStream (inst, stream, url, target, plen, post);
 }
 
 static char *nsEvaluate (const char *script, void *ndata) {
@@ -1558,7 +1559,8 @@ KMPLAYER_NO_EXPORT void NpPlayer::pluginEmbedded () {
 }
 
 KMPLAYER_NO_EXPORT void NpPlayer::requestStream (void *inst, uint32_t sid,
-        const String & url, const String & target) {
+        const String & url, const String & target,
+        unsigned post_len, const char *post) {
     URL uri (m_url, url);
     debugLog () << "NpPlayer::request " << sid << " '" << uri << "'" << endl;
     if (!target.isEmpty ()) {
@@ -1580,7 +1582,7 @@ KMPLAYER_NO_EXPORT void NpPlayer::requestStream (void *inst, uint32_t sid,
         nppStreamData (sid, data, strlen (data), this);
         nppStreamFinished (sid, NpStream::BecauseDone, this);
     } else {
-        NpStream * ns = new NpStream (this, sid, uri);
+        NpStream * ns = new NpStream (this, sid, uri, post_len, post);
         g_tree_insert (streams, (gpointer) sid, ns);
         if (url != uri.url ())
             nppStreamRedirected (sid, (const char *)uri.url ());
@@ -1678,8 +1680,13 @@ KMPLAYER_NO_EXPORT String NpPlayer::evaluateScript (const String &script) {
     return "undefined";
 }
 
-KDE_NO_CDTOR_EXPORT NpStream::NpStream (NpPlayer *p, uint32_t id, const URL & u)
+KDE_NO_CDTOR_EXPORT NpStream::NpStream (NpPlayer *p, uint32_t id, const URL &u,
+        unsigned post_len, const char *post)
  : player (p), stream (id), url (u), job (NULL), finish_reason (NoReason) {
+    if (post_len && post) {
+        post_data.resize (post_len);
+        memcpy (post_data.data (), post, post_len);
+    }
 }
 
 KDE_NO_CDTOR_EXPORT NpStream::~NpStream () {
@@ -1697,6 +1704,34 @@ KMPLAYER_NO_EXPORT void NpStream::open () {
     } else {
         bytes = 0;
         job = asyncGet (this, url.url ());
+        if (post_data.size ()) {
+            String buf;
+            int data_pos = -1;
+            bool nl = true;
+            for (int i = 0; i < post_data.size () && data_pos < 0; ++i) {
+                char c = post_data.data () [i];
+                switch (c) {
+                    case '\r':
+                        break;
+                    case '\n':
+                        if (nl)
+                            data_pos = i + 1;
+                        else
+                            job->setHeader (buf);
+                        buf.truncate (0);
+                        nl = true;
+                        break;
+                    default:
+                        nl = false;
+                        buf += Char (c);
+                }
+            }
+            job->setHeader ("Expect:");
+            if (data_pos > 0)
+                job->setHttpPostData (ByteArray (post_data.data () + data_pos,
+                            post_data.size () - data_pos));
+        }
+        job->start ();
     }
 }
 
@@ -1789,6 +1824,7 @@ bool KMPLAYER_NO_EXPORT Downloader::play (NodePtr mrl) {
                 job = asyncGet (this, m_url);
                 setState (Buffering);
                 saved_file = filename;
+                job->start ();
             }
             app_store_save_directory (application, filename);
             if (!saved_file.isEmpty ())
