@@ -266,7 +266,8 @@ public:
     //virtual String menuName () const;
 
     void pluginEmbedded ();
-    void requestStream (void *inst, uint32_t id, const String & url, const String & target);
+    void requestStream (void *inst, uint32_t id, const String & url,
+            const String & target, unsigned plen, const char *post);
     void destroyStream (void *inst, uint32_t id);
 
     void streamFinished (NpStream *ns);
@@ -292,7 +293,8 @@ public:
         BecauseDone = 0, BecauseError = 1, BecauseStopped = 2
     };
 
-    NpStream (NpPlayer *player, uint32_t stream, const URL & url);
+    NpStream (NpPlayer *player, uint32_t stream, const URL & url,
+            unsigned post_len, const char *post);
     ~NpStream ();
 
     void open ();
@@ -306,6 +308,7 @@ public:
     URL url;
     IOJob *job;
     uint32_t bytes;
+    ByteArray post_data;
     Reason finish_reason;
 private:
     NpPlayer *player;
