@@ -552,7 +552,7 @@ KMPLAYER_NO_EXPORT String GnomeVFSUrl::encode_string (const String & s) {
 KMPLAYER_NO_EXPORT bool GnomeVFSUrl::isLocalFile () const {
     if (m_vfsurl)
         return gnome_vfs_uri_is_local (m_vfsurl) ||
-            protocol () == String ("file");
+            protocol () == "file";
     return false;
 }
 
