@@ -240,16 +240,18 @@ protected:
 };
 
 struct SharedChars {
-    SharedChars (gchar * p) : ptr (p), ref_count (1) {}
+    SharedChars (gchar *p, int len) : ptr (p), ref_count (1), buf_len (len) {}
 
     // Shared requirements
-    SharedChars (const SharedChars &s) : ptr(g_strdup (s.ptr)), ref_count(1) {}
+    SharedChars (const SharedChars &s)
+        : ptr(g_strdup (s.ptr)), ref_count (1), buf_len (s.buf_len) {}
     ~SharedChars () { g_free (ptr); }
     void ref () { ref_count++; }
     void unref () { if (--ref_count <= 0) delete this; }
     int ref_count;
 
     gchar *ptr;
+    int buf_len; // excluding zero terminator
 };
 
 template <> void Shared<SharedChars>::attach (const Shared<SharedChars> &other);
@@ -261,7 +263,7 @@ public:
     GLibString (const char * str, int maxlen = -1);
     GLibString (const Char & str);
     ~GLibString ();
-    void takeUtf8 (char * p);  // p must be valid utf8
+    void takeUtf8 (char *p, int buf_len=-1);  // p must be valid utf8
     int compare (const char *str) const;
     int compare (const GLibString & str) const;
     bool operator == (const GLibString &other) const;
@@ -354,6 +356,7 @@ public:
     GLibTextStream & operator = (const GLibTextStream & other);
     bool atEnd () const;
     bool isEmpty () const;
+    const gchar *at () const;
     String release ();
     String readLine ();
 };
@@ -405,6 +408,9 @@ class IOJob {
 public:
     ~IOJob ();
 
+    void setHeader (const String &header);
+    void setHttpPostData (const ByteArray &data);
+    void start ();
     void kill (bool quiet = true);
     bool error ();
     unsigned long contentLength() const;
@@ -1144,6 +1150,10 @@ KMPLAYER_NO_EXPORT inline bool GLibTextStream::isEmpty () const {
             (m_gstring && !m_gstring->len));
 }
 
+KMPLAYER_NO_EXPORT inline const gchar *GLibTextStream::at () const {
+    return m_iter;
+}
+
 //-----------------------------------------------------------------------------
 
 KMPLAYER_NO_CDTOR_EXPORT inline GnomeVFSUrl::GnomeVFSUrl () : m_vfsurl (0L) {}
