@@ -49,10 +49,12 @@ static void clearSurface (cairo_t *cr, const IRect &rect) {
     cairo_restore (cr);
 }
 
-void ImageData::copyImage (Surface *s, int w, int h, cairo_surface_t *similar,
+void ImageData::copyImage (Surface *s, const SSize &sz, cairo_surface_t *similar,
         unsigned int *penalty, CalculatedSizer *zoom) {
     cairo_surface_t *src_sf;
     bool clear = false;
+    int w = sz.width;
+    int h = sz.height;
 
     unsigned char *bits = NULL;
     if (surface) {
@@ -355,7 +357,7 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::RegionBase *reg) {
                 Single h = bg_img->height;
                 matrix.getWH (w, h);
                 if (!s->surface)
-                    bg_img->copyImage (s, w, h, cairo_surface, &penalty);
+                    bg_img->copyImage (s, SSize(w, h), cairo_surface, &penalty);
                 if (bg_img->has_alpha)
                     cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
                 cairo_pattern_t *pat = cairo_pattern_create_for_surface (s->surface);
@@ -750,12 +752,12 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::ImageMediaType * img) {
     ImageData *id = im ? im->cached_img.ptr () : NULL;
     if (id && id->flags == ImageData::ImageScalable)
         penalty += im->render (cairo_surface, scr.size);
-    if (!id || im->isEmpty () || img->width <= 0 || img->height <= 0) {
+    if (!id || im->isEmpty () || img->size.isEmpty ()) {
         s->remove();
         return;
     }
     if (!s->surface || s->dirty)
-        id->copyImage (s, scr.width (), scr.height (), cairo_surface, &penalty, img->pan_zoom);
+        id->copyImage (s, SSize (scr.width (), scr.height ()), cairo_surface, &penalty, img->pan_zoom);
     if (id->has_alpha)
         cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
     paint (img, s, scr.point, clip_rect);
@@ -795,7 +797,7 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::TextMediaType * txt) {
     if (!s)
         return;
     if (!s->surface) {
-        txt->width = txt->height = 0;
+        txt->size = SSize ();
         s->bounds = txt->calculateBounds ();
     }
     IRect scr = matrix.toScreen (s->bounds);
@@ -833,8 +835,7 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::TextMediaType * txt) {
 
         // update bounds rect
         SRect rect = matrix.toUser (IRect (scr.point, ISize (pxw, pxh)));
-        txt->width = rect.width ();
-        txt->height = rect.height ();
+        txt->size = rect.size;
         s->bounds = txt->calculateBounds ();
 
         // update coord. for painting below
@@ -957,7 +958,7 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (RP::Imfl * imfl) {
         cairo_rectangle (cr, scr.x (), scr.y (), w, h);
         //cairo_clip (cr);
         cairo_translate (cr, scr.x (), scr.y ());
-        cairo_scale (cr, 1.0*w/(double)imfl->width, 1.0*h/(double)imfl->height);
+        cairo_scale (cr, 1.0*w/(double)imfl->size.width, 1.0*h/(double)imfl->size.height);
         if (imfl->needs_scene_img)
             cairo_push_group (cr);
         for (NodePtr n = imfl->firstChild (); n; n = n->nextSibling ())
@@ -967,9 +968,9 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (RP::Imfl * imfl) {
                 switch (n->id) {
                     case RP::id_node_viewchange:
                         if (!(int)tb->srcw)
-                            tb->srcw = imfl->width;
+                            tb->srcw = imfl->size.width;
                         if (!(int)tb->srch)
-                            tb->srch = imfl->height;
+                            tb->srch = imfl->size.height;
                         // fall through
                     case RP::id_node_crossfade:
                     case RP::id_node_fadein:
@@ -977,9 +978,9 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (RP::Imfl * imfl) {
                     case RP::id_node_fill:
                     case RP::id_node_wipe:
                         if (!(int)tb->w)
-                            tb->w = imfl->width;
+                            tb->w = imfl->size.width;
                         if (!(int)tb->h)
-                            tb->h = imfl->height;
+                            tb->h = imfl->size.height;
                         n->accept (this);
                         break;
                 }
@@ -1014,13 +1015,13 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (RP::Fadein * fi) {
         if (im && img->surface ()) {
             Single sx = fi->srcx, sy = fi->srcy, sw = fi->srcw, sh = fi->srch;
             if (!(int)sw)
-                sw = img->width;
+                sw = img->size.width;
             if (!(int)sh)
-                sh = img->height;
+                sh = img->size.height;
             if ((int)fi->w && (int)fi->h && (int)sw && (int)sh) {
                 if (!img->img_surface->surface)
                     im->cached_img->copyImage (img->img_surface,
-                            img->width, img->height, cairo_surface, &penalty);
+                            img->size, cairo_surface, &penalty);
                 cairo_matrix_t matrix;
                 cairo_matrix_init_identity (&matrix);
                 float scalex = 1.0 * sw / fi->w;
@@ -1067,13 +1068,13 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (RP::Crossfade * cf) {
         if (im && img->surface ()) {
             Single sx = cf->srcx, sy = cf->srcy, sw = cf->srcw, sh = cf->srch;
             if (!(int)sw)
-                sw = img->width;
+                sw = img->size.width;
             if (!(int)sh)
-                sh = img->height;
+                sh = img->size.height;
             if ((int)cf->w && (int)cf->h && (int)sw && (int)sh) {
                 if (!img->img_surface->surface)
                     im->cached_img->copyImage (img->img_surface,
-                            img->width, img->height, cairo_surface, &penalty);
+                            img->size, cairo_surface, &penalty);
                 cairo_save (cr);
                 cairo_matrix_t matrix;
                 cairo_matrix_init_identity (&matrix);
@@ -1109,9 +1110,9 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (RP::Wipe * wipe) {
             Single w = wipe->w, h = wipe->h;
             Single sx = wipe->srcx, sy = wipe->srcy, sw = wipe->srcw, sh = wipe->srch;
             if (!(int)sw)
-                sw = img->width;
+                sw = img->size.width;
             if (!(int)sh)
-                sh = img->height;
+                sh = img->size.height;
             if (wipe->direction == RP::Wipe::dir_right) {
                 Single dx = w * 1.0 * wipe->progress / 100;
                 tx = x -w + dx;
@@ -1135,7 +1136,7 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (RP::Wipe * wipe) {
             if ((int)w && (int)h) {
                 if (!img->img_surface->surface)
                     im->cached_img->copyImage (img->img_surface,
-                            img->width, img->height, cairo_surface, &penalty);
+                            img->size, cairo_surface, &penalty);
                 cairo_matrix_t matrix;
                 cairo_matrix_init_identity (&matrix);
                 float scalex = 1.0 * sw / wipe->w;
@@ -1326,7 +1327,7 @@ KDE_NO_EXPORT void MouseVisitor::visit (SMIL::RegionBase *region) {
                 }
             }// else // MsgEventClicked
             if (notify_receivers) {
-                Posting mouse_event (region, event);
+                Posting mouse_event (region, region, event);
                 region->deliver (event, &mouse_event);
             }
             if (pass_event) {
@@ -1577,6 +1578,7 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea ()
    last_repaint_time (0),
    next_repaint_time (0),
    penalty (0),
+   cur_timeout (0),
    m_repaint_timer (0),
    m_fullscreen (false),
    m_event_filter_on (false),
@@ -1647,10 +1649,9 @@ KDE_NO_EXPORT void ViewArea::paintEvent (const IRect & rect) {
 KDE_NO_EXPORT void ViewArea::updateSurfaceBounds () {
     Single x, y, w = width (), h = height ();
     Mrl *mrl = surface->node ? surface->node->mrl () : NULL;
-    if (w > 0 && h > 0 &&
-            mrl && mrl->width > 0 && mrl->height > 0) {
+    if (w > 0 && h > 0 && mrl && !mrl->size.isEmpty ()) {
         double wasp = (double) w / h;
-        double masp = (double) mrl->width / mrl->height;
+        double masp = (double) mrl->size.width / mrl->size.height;
         if (wasp > masp) {
             Single tmp = w;
             w = masp * h;
@@ -1660,8 +1661,8 @@ KDE_NO_EXPORT void ViewArea::updateSurfaceBounds () {
             h = Single (w / masp);
             y += (tmp - h) / 2;
         }
-        surface->xscale = 1.0 * w / mrl->width;
-        surface->yscale = 1.0 * h / mrl->height;
+        surface->xscale = 1.0 * w / mrl->size.width;
+        surface->yscale = 1.0 * h / mrl->size.height;
     } else {
         surface->xscale = 1.0;
         surface->yscale = 1.0;
